from django.utils import timezone
from .models import Theme
from .models import ThemeCss
from .models import ThemeJs

def register_theme(name, code, css_files, js_files):
    theme_object = Theme()
    theme_object.name = name
    theme_object.code = code
    theme_object.published = True
    theme_object.published_time = timezone.now()
    theme_object.save()

    order = 0
    for css_file in css_files:
        order += 1000
        css_object = ThemeCss()
        css_object.theme = theme_object
        css_object.css = css_file
        css_object.order = order
        css_object.save()
    
    order = 0
    for js_file in js_files:
        order += 1000
        js_object = ThemeCss()
        js_object.theme = theme_object
        js_object.css = js_file
        js_object.order = order
        js_object.save()



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class DjangoPowerCmsConfig(AppConfig):
    name = 'django_power_cms'
    verbose_name = _("Django Power CMS")

    def ready(self):
        from django.conf import settings
        if hasattr(settings, "ADMIN_REORDER"):
            for app_index in range(len(settings.ADMIN_REORDER)):
                app_setting = settings.ADMIN_REORDER[app_index]
                if isinstance(app_setting, str):
                    if app_setting != "django_power_cms":
                        continue
                    else:
                        app_setting = {"app": "django_power_cms"}
                        settings.ADMIN_REORDER[app_index] = app_setting
                else:
                    if app_setting["app"] != "django_power_cms":
                        continue
                app_setting["models"] =  [
                    {"model":  'django_power_cms.Site', "label": _("Site Manager")},
                    {"model": 'django_power_cms.Page', "label": _("Page Manager")},
                    {"model": 'django_power_cms.Widget', "label": _("Widget Manager")},
                    {"model": 'django_power_cms.Article', "label": _("Article Manager")},
                    {"model": 'django_power_cms.Template', "label": _("Template Manager")},
                    {"model": 'django_power_cms.Theme', "label": _("Theme Manager")},
                ]



from django.contrib import admin
from mptt.admin import DraggableMPTTAdmin
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _
from django_readedit_switch_admin.admin import DjangoReadEditSwitchAdminMixin
from django_force_disable_permissions_admin.admin import DjagnoForceDisablePermissionsAdminMixin
from django_msms_admin.admin import DjangoMsmsAdmin
from django_msms_admin.admin import DjangoSubclassAdmin
from .models import Template
from .models import TemplateSlot
from .models import Site
from .models import Page
from .models import PageWidget
from .models import Widget
from .models import StaticHtmlWidget
from .models import CarouselWidget
from .models import CarouselWidgetImage
from .models import Theme
from .models import ThemeCss
from .models import ThemeJs
from .models import WidgetLink
from .models import StaticListWidget
from .models import StaticListItem
from .models import TopbarWidget
from .models import TopbarBrand
from .models import Article
from .models import ArticleContentImage
from .models import ArticleListWidget

class PageWidgetInline(admin.TabularInline):
    model = PageWidget

class PageAdmin(DraggableMPTTAdmin):
    list_display = ["tree_actions", "display_title", "code"]
    list_display_links = ["display_title"]
    inlines = [
        PageWidgetInline,
    ]

    def display_title(self, instance):
        return format_html(
            '<div style="text-indent:{}px">{}</div>',
            instance._mpttfield('level') * self.mptt_level_indent,
            instance.name,
        )
    display_title.short_description = _('Title')


class SiteAdmin(admin.ModelAdmin):
    list_display = ["name", "code", "published", "published_time", "preview_link"]
    list_filter = ["published"]
    search_fields = ["name", "code"]

    def preview_link(self, obj):
        return format_html(
            """<a href="{0}" target="_blank">{1}</a>""",
            obj.get_absolute_url(),
            _("Preview"),
        )

    preview_link.short_description = _("Preview")


class ThemeCssInline(admin.TabularInline):
    model = ThemeCss

class ThemeJsInline(admin.TabularInline):
    model = ThemeJs

class ThemeAdmin(admin.ModelAdmin):
    list_display = ["name", "description", "is_default"]
    list_filter = ["is_default"]
    search_fields = ["name", "description"]
    inlines = [
        ThemeCssInline,
        ThemeJsInline,
    ]


class WidgetLinkInline(admin.TabularInline):
    model = WidgetLink
    extra = 0

class StaticHtmlWidgetAdmin(DjangoSubclassAdmin, admin.ModelAdmin):
    list_dipslay = ["name"]
    inlines = [
        WidgetLinkInline,
    ]

class CarouselWidgetImageInline(admin.TabularInline):
    model = CarouselWidgetImage
    extra = 0

class CarouselWidgetAdmin(DjangoSubclassAdmin, admin.ModelAdmin):
    list_dipslay = ["name"]
    inlines = [
        WidgetLinkInline,
        CarouselWidgetImageInline,
    ]

class StaticListItemInline(admin.StackedInline):
    model = StaticListItem
    extra = 0
    fieldsets = [
        [None, {
            "fields": [
                ("title", "url"),
                ("target", "order"),
                ("label", "label_class"),
            ]
        }]
    ]


class StaticListWidgetAdmin(DjangoSubclassAdmin, admin.ModelAdmin):
    list_display = ["name"]
    inlines = [
        WidgetLinkInline,
        StaticListItemInline,
    ]

class TopbarBrandInline(admin.TabularInline):
    model = TopbarBrand
    extra = 0

class TopbarWidgetAdmin(DjangoSubclassAdmin, admin.ModelAdmin):
    list_display = ["name"]
    inlines = [
        WidgetLinkInline,
        TopbarBrandInline,
    ]


class ArticleContentImageInline(admin.TabularInline):
    model = ArticleContentImage
    extra = 0

class ArticleAdmin(DjangoReadEditSwitchAdminMixin, DraggableMPTTAdmin, admin.ModelAdmin):
    list_display = ["tree_actions", "display_title", "published", "published_time"]
    list_display_links = ["display_title"]
    inlines = [
        ArticleContentImageInline
    ]

    def display_title(self, instance):
        return format_html(
            '<div style="text-indent:{}px">{}</div>',
            instance._mpttfield('level') * self.mptt_level_indent,
            instance.title,
        )
    display_title.short_description = _('Title')

class WidgetAdmin(DjangoMsmsAdmin, admin.ModelAdmin):
    list_display = ["name", "type_name"]
    list_filter = ["type_name"]
    search_fields = ["name"]


class ArticleListWidgetAdmin(DjangoSubclassAdmin, admin.ModelAdmin):
    list_display = ["name"]
    inlines = [
        WidgetLinkInline,
    ]

class TemplateSlotInline(admin.TabularInline):
    model = TemplateSlot
    extra = 0

class TemplateAdmin(admin.ModelAdmin):
    list_display = ["name", "app_label", "template", "preview_image"]
    list_filter = ["app_label"]
    search_fields = ["name", "description", "template"]
    inlines = [
        TemplateSlotInline,
    ]

admin.site.register(Template, TemplateAdmin)
admin.site.register(Site, SiteAdmin)
admin.site.register(Page, PageAdmin)
admin.site.register(Widget, WidgetAdmin)
admin.site.register(Theme, ThemeAdmin)
admin.site.register(CarouselWidget, CarouselWidgetAdmin)
admin.site.register(StaticHtmlWidget, StaticHtmlWidgetAdmin)
admin.site.register(StaticListWidget, StaticListWidgetAdmin)
admin.site.register(TopbarWidget, TopbarWidgetAdmin)
admin.site.register(Article, ArticleAdmin)
admin.site.register(ArticleListWidget, ArticleListWidgetAdmin)


# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

requires = [
    "pillow==6.2.2",
    "django==2.2.10",
    "fastutils>=0.9.0",

    "django-modeladmin-reorder>=0.3.1",
    "django-ckeditor-5>=0.0.5",
    "django-mptt>=0.11.0",

    "django-static-jquery3>=3.3.1.1",
    "django-static-bootstrap>=3.3.7.1",
    "django-static-fontawesome>=5.12.1.1",
    "django-static-ionicons>=2.0.1.2",
    "django-fullname-localization>=0.1.0",
    "django-msms-admin>=0.1.1",
]

setup(
    name="django-power-cms",
    version="0.1.0",
    description="A power content management system based on django admin framework.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django power cms"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_power_cms_example", "django_power_cms_example.migrations", "django_power_cms_demo"]),
    py_modules=["django_power_cms"],
    zip_safe=False,
    include_package_data=True,
)


from django.utils import timezone
from .models import Template

def register_template(name, code, template, slots):
    pass
    try:
        template_object = Template.objects.get(code=code)
        changed_flag = False
        if name != template_object.name:
            template_object.name = name
            changed_flag = True
        if template != template_object.template:
            template_object.template = template
            changed_flag = True
        if slots != template_object.slots:
            template_object.slots = slots
            changed_flag = True
        if changed_flag:
            template_object.save()
    except Template.DoesNotExist:
        template_object = Template()
        template_object.name = name
        template_object.code = code
        template_object.template = template
        template_object.published = True
        template_object.published_time = timezone.now()
        template_object.save()
